@@ -9,22 +9,22 @@ use AnyEvent::Gearman;
 use AnyEvent::Gearman::Worker::RetryConnection;
 
 
-our $VERSION = '0.5'; # VERSION
+our $VERSION = '0.6'; # VERSION
 
 
 has 'pid' => (is => 'rw', isa => 'Str', default=>sub{return $$;});
 
-has 'servers' => (is => 'rw', isa => 'ArrayRef',required => 1);
+has 'job_servers' => (is => 'rw', isa => 'ArrayRef',required => 1);
 
 has 'prefix' => (is => 'rw', isa => 'Str', default=>'IPC::AnyEvent::Gearman#');
 
-has 'on_receive' => (is => 'rw', isa=>'CodeRef', 
-    default=>sub{return sub{WARN 'You need to set on_receive function'};}
+has 'on_recv' => (is => 'rw', isa=>'CodeRef', 
+    default=>sub{return sub{WARN 'You need to set on_recv function'};}
 );
-has 'on_send' => (is => 'rw', isa=>'CodeRef', 
+has 'on_sent' => (is => 'rw', isa=>'CodeRef', 
     default=>sub{return sub{INFO 'Send OK '.$_[0]};}
 );
-has 'on_sendfail' => (is => 'rw', isa=>'CodeRef', 
+has 'on_fail' => (is => 'rw', isa=>'CodeRef', 
     default=>sub{return sub{WARN 'Send FAIL '.$_[0]};}
 );
 
@@ -32,7 +32,7 @@ has 'client' => (is=>'rw', lazy=>1, isa=>'Object',
 default=>sub{
     DEBUG 'lazy client';
     my $self = shift;
-    return gearman_client @{$self->servers()};
+    return gearman_client @{$self->job_servers()};
 },
 );
 
@@ -53,13 +53,13 @@ after 'prefix' => sub{
     }
 };
 
-after 'servers' => sub{
+after 'job_servers' => sub{
     my $self = shift;
     if( @_ && $self->{listening}){
         $self->_renew_connection();    
     }
     if( @_ ){
-        $self->client( gearman_client @{$self->servers()} );
+        $self->client( gearman_client @{$self->job_servers()} );
     }
 };
 
@@ -71,20 +71,23 @@ sub listen{
 
 sub channel{
     my $self = shift;
-    return $self->prefix().$self->pid();
+    my $pid = shift;
+    $pid = $self->pid() unless( $pid );
+    return $self->prefix().$pid;
 }
 
 sub send{
     my $self = shift;
+    my $target_pid = shift;
     my $data = shift;
     $self->client->add_task(
-        $self->channel() => $data,
+        $self->channel($target_pid) => $data,
         on_complete => sub{
             my $result = $_[1];
-            $self->on_send()->($self->channel(),$_[1]);
+            $self->on_sent()->($self->channel($target_pid),$_[1]);
         },
         on_fail => sub{
-            $self->on_sendfail()->($self->channel());
+            $self->on_fail()->($self->channel($target_pid));
         }
     );
 }
@@ -92,13 +95,13 @@ sub send{
 sub _renew_connection{
     my $self = shift;
     DEBUG "new Connection";
-    my $worker = gearman_worker @{$self->servers()};
+    my $worker = gearman_worker @{$self->job_servers()};
     $worker = AnyEvent::Gearman::Worker::RetryConnection::patch_worker($worker);
     $self->worker( $worker );
     $self->worker->register_function(
         $self->prefix().$self->pid() => sub{
             my $job = shift;
-            my $res = $self->on_receive()->($job->workload);
+            my $res = $self->on_recv()->($job->workload);
             $res = '' unless defined($res);
             $job->complete($res);
         }
@@ -118,7 +121,7 @@ IPC::AnyEvent::Gearman - IPC through gearmand.
 
 =head1 VERSION
 
-version 0.5
+version 0.6
 
 =head1 SYNOPSIS
 
@@ -126,8 +129,8 @@ version 0.5
     use IPC::AnyEvent::Gearman;
     
     #receive    
-    my $recv = IPC::AnyEvent::Gearman->new(servers=>['localhost:9999']);
-    $recv->on_receive(sub{
+    my $recv = IPC::AnyEvent::Gearman->new(job_servers=>['localhost:9999']);
+    $recv->on_recv(sub{
         my $msg = shift;
         print "received msg : $data\n";
         return "OK";#result
@@ -150,7 +153,7 @@ version 0.5
 This can be any value not just PID.
 It is filled own PID by default.
 
-=head2 servers
+=head2 job_servers
 
 ArrayRef of hosts.
 
@@ -159,20 +162,20 @@ ArrayRef of hosts.
 When register function, it uses prefix+pid as function name.
 It is filled 'IPC::AnyEvent::Gearman#' by default. 
 
-=head2 on_receive
+=head2 on_recv
 
-on_receive Hander.
+on_recv Hander.
 First argument is DATA which is sent.
 This can be invoked after listen().
 
-=head2 on_send
+=head2 on_sent
 
-on_send handler.
+on_sent handler.
 First argument is a channel string.
 
-=head2 on_sendfail
+=head2 on_fail
 
-on_sendfail handler.
+on_fail handler.
 First argument is a channel string.
 
 =head1 METHODS
@@ -188,9 +191,10 @@ get prefix+pid
 =head2 send
 
 To send data to process listening prefix+pid, use this.
-You must set 'pid' or 'prefix' attribute on new() method.
 
-    my $send = IPC::AnyEvent::Gearman->new(pid=>1223);
+    my $sender = IPC::AnyEvent::Gearman->new(job_servers=>['localhost:9998']);
+    $sender->prefix('MYIPC');
+    $sender->send(1201,'DATA');
 
 =head1 AUTHOR
 
